module.exports = defineTest({
	description: 'does not deoptimize the entire superclass when reassigning a property'
});
